@@ -55,8 +55,8 @@ impl<'de, T: Deserialize<'de>> Deserialize<'de> for KeyMap<T> {
 #[cfg(test)]
 mod tests {
     use crate::{
-        compiler::{CaoIr, Lane},
-        prelude::CaoProgram,
+        compiler::{CaoProgram, Lane, Module},
+        prelude::CaoCompiledProgram,
     };
 
     use super::*;
@@ -104,12 +104,18 @@ mod tests {
     #[test]
     fn can_serialize_program_cbor() {
         let program = crate::compiler::compile(
-            &CaoIr {
-                lanes: vec![Lane {
-                    name: Some("poggers".into()),
-                    arguments: vec![],
-                    cards: vec![],
-                }],
+            CaoProgram {
+                module: Module {
+                    lanes: vec![Lane {
+                        name: "main".into(),
+                        arguments: vec![],
+                        cards: vec![],
+                    }]
+                    .into_iter()
+                    .map(|lane| (lane.name.clone(), lane))
+                    .collect(),
+                    submodules: Default::default(),
+                },
             },
             None,
         )
@@ -118,6 +124,6 @@ mod tests {
         let mut payload = Vec::new();
         ciborium::ser::into_writer(&program, &mut payload).unwrap();
 
-        let _: CaoProgram = ciborium::de::from_reader(payload.as_slice()).unwrap();
+        let _: CaoCompiledProgram = ciborium::de::from_reader(payload.as_slice()).unwrap();
     }
 }
