@@ -7,13 +7,16 @@ def test_compile_and_run():
     """
 
     PROGRAM_YAML = """
-lanes:
-    - cards:
-        - ty: ScalarInt
-          val: 5
-        - ty: ScalarInt
-          val: 5
-        - ty: Add
+module:
+    lanes:
+        main: 
+            name: main
+            cards:
+                - ty: ScalarInt
+                  val: 5
+                - ty: ScalarInt
+                  val: 5
+                - ty: Add
 """
 
     program = caoc.CompilationUnit.from_yaml(PROGRAM_YAML)
